==> neo4j-capabilities-4.4.19-sources.jar: org/neo4j/capabilities/Capabilities.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.capabilities;

/**
 * Provides users access to declared capability values.
 */
public interface Capabilities
{
    /**
     * Gets a capability value identified by the provided capability declaration.
     *
     * @param capability the capability that is being queried.
     * @param <T>        the type of the capability value.
     * @return the capability value set, or null if it is not in the set of declared capabilities.
     */
    <T> T get( Capability<T> capability );

    /**
     * Gets a capability value identified by the provided capability declaration.
     *
     * @param name the name of the capability that is being queried.
     * @return the capability value set, or null if it is not in the set of declared capabilities.
     */
    Object get( Name name );
}

==> neo4j-capabilities-5.6.0-sources.jar: org/neo4j/capabilities/Capabilities.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.capabilities;

/**
 * Provides users access to declared capability values.
 */
public interface Capabilities {
    /**
     * Gets a capability value identified by the provided capability declaration.
     *
     * @param capability the capability that is being queried.
     * @param <T>        the type of the capability value.
     * @return the capability value set, or null if it is not in the set of declared capabilities.
     */
    <T> T get(Capability<T> capability);

    /**
     * Gets a capability value identified by the provided capability declaration.
     *
     * @param name the name of the capability that is being queried.
     * @return the capability value set, or null if it is not in the set of declared capabilities.
     */
    Object get(Name name);
}
